use super::{PossessionData, PossessionType};
use ansi::ansi;
use once_cell::sync::OnceCell;

pub fn data() -> &'static Vec<(PossessionType, PossessionData)> {
    static D: OnceCell<Vec<(PossessionType, PossessionData)>> = OnceCell::new();
    &D.get_or_init(|| {
        vec![
            (
                PossessionType::CausticSoda,
                PossessionData {
                    display: "bottle of caustic soda",
                    details: ansi!("A rigid blue plastic bottle labelled as containing caustic soda. Apparently it's highly corrosive and shouldn't be eaten."),
                    aliases: vec!["chemical", "sodium hydroxide", "caustic soda"],
                    weight: 100,
                    ..Default::default()
                },
            ),
            (
                PossessionType::VinylAcetate,
                PossessionData {
                    display: "jar of vinyl acetate",
                    details: ansi!("A glass jar containing a colourless liquid, labelled as vinyl acetate. Apparently it's both flammable and harmful."),
                    aliases: vec!["chemical", "monomer", "vinyl acetate"],
                    weight: 100,
                    ..Default::default()
                },
            ),
            (
                PossessionType::Azobisisobutyronitrile,
                PossessionData {
                    display: "tube of azobisisobutyronitrile",
                    details: ansi!("A small tube containing some white crystals. Apparently they are flammable and harmful, and are also known as AIBN."),
                    aliases: vec!["chemical", "initiator", "AIBN", "azobisisobutyronitrile"],
                    weight: 20,
                    ..Default::default()
                },
            ),
            (
                PossessionType::Borax,
                PossessionData {
                    display: "box of borax",
                    details: ansi!("A cardbox box containing some white powder, labelled as borax. Apparently it's very poisonous to ants."),
                    aliases: vec!["chemical", "borax"],
                    weight: 100,
                    ..Default::default()
                },
            ),
            (
                PossessionType::HydrochloricAcid,
                PossessionData {
                    display: "jar of hydrochloric acid",
                    details: ansi!("A glass jar containing some liquid. It's labelled as being concentrated hydrochloric acid, and apparently it's very corrosive and can cause damage to the skin, lungs and eyes."),
                    aliases: vec!["chemical", "acid", "hydrochloric acid"],
                    weight: 100,
                    ..Default::default()
                },
            ),
        ]
    })
}
